% !TeX root = ./demo.tex
\NeedsTeXFormat{LaTeX2e}
\RequirePackage{expl3}
\ProvidesExplClass{jhl}{2020.7.1}{1.0}{zsben}
\RequirePackage { xparse, xtemplate, l3keys2e }
\clist_map_inline:nn { expl3, xparse, xtemplate, l3keys2e }
  {
    \@ifpackagelater {#1} { 2011/03/13 }
      { } { \msg_error:nnn { jhl } { l3-too-old } {#1} }
  }
\msg_new:nnn { jhl } { l3-too-old }
  {
    Package ~ "#1" ~ is ~ too ~ old. \\\\
    Please ~ update ~ an ~ up-to-date ~ version ~ of ~ the ~ bundles \\
    "l3kernel" ~ and ~ "l3packages" ~ using ~ your ~ TeX ~ package \\
    manager ~ or ~ from ~ CTAN.
  }
\cs_new:Npn \__jhl_msg_new:nn  { \msg_new:nnn { jhl } }

\LoadClass { article }
\RequirePackage
  {
    amsmath,
    amssymb,
    geometry,
    fancyhdr,
    lastpage,
    ntheorem,
    graphicx,
    caption,
    xcolor,
    titlesec,
    newtxmath,
    newtxtext,
    enumitem
  }

\geometry
  {
    includeheadfoot,
    vmargin = 1.5cm,
    hmargin = 2.3cm,
    headsep = 0.5cm,
  }

\tl_new:N \g__jhl_theme_color
\tl_gset:Nn \g__jhl_theme_color { green ! 40 ! blue }

\fancyhf { }
\fancyhead [ L ] { \g__jhl_short_author_tl \; \textit \g__jhl_short_title_tl }
\fancyhead [ R ] { Page ~ \thepage{} ~ of ~ \pageref* { LastPage } }
\RenewDocumentCommand \headrule { }
  {
    \group_begin:
      \fancyplain
        {
          \cs_set_eq:NN \headrulewidth \plainheadrulewidth
        } { }
      \__jhl_make_headrule:
    \group_end:
  }
\cs_new_protected:Nn \__jhl_make_headrule:
  {
    \makebox [ 0pt ] [ l ]
      {
        \rule [ .63\baselineskip ] { \headwidth } { .4pt }
      }
    \color \g__jhl_theme_color
    \rule [ .7\baselineskip ] { \headwidth } { 1pt }
  }

\NewDocumentCommand \url { m } { \texttt { #1 } }
\fancypagestyle { plain }
  {
    \fancyhf { }
    \fancyhead [ L ]
      { 
        \textrm \g__jhl_short_author_tl \; \textsl \g__jhl_short_title_tl \\
        \url { https://doi.org/\g__jhl_doi_tl }
      }
    \fancyhead [ R ]
      { 
        \textrm Official ~ journal ~ of ~ the ~ JHL ~
        \int_to_arabic:n \g__jhl_journal_page_begin_int
        -
        \int_to_arabic:n \g__jhl_journal_page_end_int \\
        \url { http://www.light-am.com/ }
      }
    \fancyfoot { \includegraphics [ width = \linewidth ] { openAccess.png } }
  }
\pagestyle { fancy }


\NewDocumentCommand \shortauthor { m }
  {
    \tl_set:Nn \g__jhl_short_author_tl { #1 }
  }
\NewDocumentCommand \shorttitle { m }
  {
    \tl_set:Nn \g__jhl_short_title_tl { #1 }
  }

\int_new:N \g__jhl_journal_page_begin_int
\int_new:N \g__jhl_journal_page_end_int
\NewDocumentCommand \journalpage { m m }
  {
    \int_set:Nn \g__jhl_journal_page_begin_int { #1 }
    \int_set:Nn \g__jhl_journal_page_end_int { #2 }
  }

\NewDocumentCommand \doi { m }
  {
    \tl_set:Nn \g__jhl_doi_tl { #1 }  
  }

\DeclareDocumentCommand \title { m }
  {
    \tl_set:Nn \l__jhl_title_tl
      {
        \group_begin:
          \raggedright \fontsize{28pt}{35pt} \bfseries #1 \par
        \group_end:
      }
  }

  \seq_new:N \g__jhl_authors_seq
  \seq_new:N \g__jhl_addresses_seq
  \seq_new:N \g__jhl_thanks_seq
  % #1 = author
  % #2 = labels
  \DeclareDocumentCommand \author { o m }
    {
      \IfNoValueTF {#1}
        { \seq_put_right:Nn \g__jhl_authors_seq {#2} }
        {
          \seq_put_right:Nn \g__jhl_authors_seq
            { 
              #2
              \clist_set:Nx \l_tmpa_clist
                { \clist_map_function:nN {#1} \__jhl_ref:n }
              \textsuperscript { \clist_use:Nn \l_tmpa_clist {\hspace*{0.5em}} }
            }
        }
    }
  \cs_new:Npn \__jhl_ref:n #1
    { \exp_not:N \ref {#1} , }

\DeclareDocumentCommand \address { o m }
  {
    \IfNoValueTF { #1 }
      { \seq_put_right:Nn \g__jhl_addresses_seq { \hspace* { 2ex } \textit { #2 } } }
      {
        \seq_put_right:Nn \g__jhl_addresses_seq
          {
            \refstepcounter { jhl@address }
            \label { #1 }
            \hspace* { 2ex }
            \textsuperscript { \int_use:c { c@jhl@address } }
            \textit { #2 }
          }
      }
  }
\newcounter { jhl@address }
\setcounter { jhl@address } { 0 }

\DeclareDocumentCommand \thanks { o m }
  {
    \IfNoValueTF { #1 }
      { \seq_put_right:Nn \g__jhl_thanks_seq { \hspace* { 2ex } \textsf { #2 } } }
      {
        \seq_put_right:Nn \g__jhl_thanks_seq
          {
            \refstepcounter { jhl@thanks }
            \label { #1 }
            \hspace* { 2ex }
            \textsuperscript { \thejhl@thanks }
            \textsf { #2 }
          }
      }
  }
\newcounter { jhl@thanks }
\setcounter { jhl@thanks } { 0 }
\RenewExpandableDocumentCommand \thejhl@thanks { } { \fnsymbol { jhl@thanks } }

\DeclareDocumentEnvironment { abstract } { +b }
  {
    \cs_new_protected:Nn \__jhl_abstract:
      {
        \group_begin:
          \group_begin:
            \large \bfseries \color \g__jhl_theme_color
            Abstract
          \group_end:
          \par \vspace { 1ex }
          #1 \par
        \group_end:
      }
  } { }

\DeclareDocumentCommand \keywords { m }
  {
    \par \bfseries Keywords: ~ \normalfont #1 \par
  }

\RequirePackage [ most ] { tcolorbox }
\newtcolorbox { jhl@name@tcb }
  { 
    colback = white,
    colframe = black,
    boxrule = 1pt
  }
\newtcolorbox { jhl@abstract@tcb }
  {
    colback = white,
    colframe = \g__jhl_theme_color,
    boxrule = 1pt
  }
\newtcolorbox { jhl@figure@tcb }
  { 
    colback = white,
    colframe = \g__jhl_theme_color,
    boxrule = 1pt
  }


%\newtcolorbox { jhl@table@tcb }
%  { 
%    colback = white,
%    colframe = \g__jhl_theme_color,
%    boxrule = 1pt
%  }

\DeclareDocumentCommand \maketitle { }
  {
    \thispagestyle { plain }
    \twocolumn
      [
        \vspace* { 2em }
        \l__jhl_title_tl
        \par 
        \begin{jhl@name@tcb}
          \large
          \seq_use:Nnnn \g__jhl_authors_seq { ~ and ~ } { ,~ } { ,\hspace*{0.5em}and ~ }
          \par \vspace { -.5em }
          \rule { 3cm } { .4pt }
          \par \normalsize
          \seq_use:Nn \g__jhl_addresses_seq { \par }
          \par
          \seq_use:Nn \g__jhl_thanks_seq { \par }
        \end{jhl@name@tcb}
        \par
        \begin{jhl@abstract@tcb}
          \__jhl_abstract:
        \end{jhl@abstract@tcb}
        \par
        \vspace { 1em }
      ]
  }

\titleformat
  { \section }
  { \large \bfseries \color \g__jhl_theme_color }
  { \arabic{section} }
  { 1em }
  { }
\titlespacing
  {\section} 
  {0pt}
  {0pt}
  {0.5pt}
\titleformat
  { \subsection }
  { \bfseries \color \g__jhl_theme_color }
  { \thesection . \arabic{subsection} }
  { 1em }
  { }
\titlespacing
  {\subsection} 
  {0pt}
  {0pt}
  {0.5pt}
\titlespacing
  {\paragraph}
  {0pt}
  {0pt}
  {0.5pt}


\cs_new_eq:NN \__jhl_figure_begin \figure
\cs_new_eq:NN \__jhl_figure_end \endfigure
\RenewDocumentEnvironment { figure } { O{} +b }
  {
    \__jhl_figure_begin [ #1 ]
    \begin { jhl@figure@tcb }
    #2
  }
  {
    \end { jhl@figure@tcb }
    \__jhl_figure_end
  }

%\cs_new_eq:NN \__jhl_table_begin \table
%\cs_new_eq:NN \__jhl_table_end \endtable
%\RenewDocumentEnvironment { table } { O{} +b }
%  {
%    \__jhl_table_begin [ #1 ]
%    \begin { jhl@table@tcb }
%    #2
%  }
%  {
%    \end { jhl@table@tcb }
%    \__jhl_table_end
%  }

\RenewDocumentCommand \figurename { } { Fig. }
\captionsetup [figure]{labelsep=period,labelfont=bf}
% \RenewDocumentCommand \tablename { } { Tab }

\NewDocumentEnvironment { acknowledgement } { }
  {
    \subsection* { Acknowledgement }
    \sffamily
  }
  { }
\NewDocumentEnvironment { authorcontributions } { }
  {
    \subsection* { Author ~ contributions }
    \sffamily
  }
  { }
\NewDocumentEnvironment { conflictofinterest } { }
  {
    \subsection* { Conflict ~ of ~ interest }
    \sffamily
  }
  { }
\NewDocumentEnvironment { reference } { }
  {
    \subsection* { Reference }
    \sffamily
  }
  { }

\RequirePackage
  [
    colorlinks,
    urlcolor = blue
  ]
  { hyperref }